==> 2.4.zip: piwigo/language/sh_RS/upgrade.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2012 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+



$lang['Upgrade'] = "Nadogradnja";
$lang['This page proposes to upgrade your database corresponding to your old version of Piwigo to the current version. The upgrade assistant thinks you are currently running a <strong>release %s</strong> (or equivalent).'] = "Ova stranica predlaže nadogradnju baze sa Piwigo stare verzije na novu.
Asistent nadogradnje procenjuje da trenutno koristite <strong>izdanje %s</strong> (ili ekvivalentnu).";
$lang['Upgrade from version %s to %s'] = "Nadogradnja sa verzije %s na %s";
$lang['Statistics'] = "Statistika";
$lang['total upgrade time'] = "ukupno vreme nadogradnje";
$lang['total SQL time'] = "ukupno SQL vreme";
$lang['SQL queries'] = "SQL upiti";
$lang['Upgrade informations'] = "Informacije o nadogradnji";
$lang['Perform a maintenance check in [Administration>Tools>Maintenance] if you encounter any problem.'] = "Izvršiti proveru održavanja u [Administracija>Alati>Održavanje] ako naiđšete na neki problem.";
$lang['As a precaution, following plugins have been deactivated. You must check for plugins upgrade before reactiving them:'] = "Kao meru predostrožnost, dati dodaci su deaktivirani. Morate proveriti za nadogradnju dodataka pre nego ih ponovo aktivirate :";
$lang['Only administrator can run upgrade: please sign in below.'] = "Samo administrator može da pokrene nadogradnju: prijavite se ispod.";
$lang['You do not have access rights to run upgrade'] = "Nemate pristupna prava da pokrenete nadogradnju";
$lang['All sub-albums of private albums become private'] = "Sve podkategorije privatnih kategorija postaju privatne";
$lang['User permissions and group permissions have been erased'] = "Korisničke i grupne dozvole su obrisane";
$lang['Only thumbnails prefix and webmaster mail address have been saved from previous configuration'] = "Samo prefix za povezne sličice i webmaster e-mail adresa su sačuvane iz prethodne konfiguracije";
$lang['As a precaution, following themes have been deactivated. You must check for themes upgrade before reactiving them:'] = 'Iz predustrožnosti, sledeće teme su deaktivirane. Proverite nadogradnje tema pre nego što ih reaktivirate:';
$lang['In <i>%s</i>, before <b>?></b>, insert:'] = 'U <i>%s</i>, pre <b>?></b>, dodajte:';
?>

==> 14.5.0.zip: piwigo/language/sh_RS/upgrade.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+



$lang['Upgrade'] = "Nadogradnja";
$lang['This page proposes to upgrade your database corresponding to your old version of Piwigo to the current version. The upgrade assistant thinks you are currently running a <strong>release %s</strong> (or equivalent).'] = "Ova stranica predlaže nadogradnju baze sa Piwigo stare verzije na novu.
Asistent nadogradnje procenjuje da trenutno koristite <strong>izdanje %s</strong> (ili ekvivalentnu).";
$lang['Upgrade from version %s to %s'] = "Nadogradnja sa verzije %s na %s";
$lang['Statistics'] = "Statistika";
$lang['total upgrade time'] = "ukupno vreme nadogradnje";
$lang['total SQL time'] = "ukupno SQL vreme";
$lang['SQL queries'] = "SQL upiti";
$lang['Upgrade informations'] = "Informacije o nadogradnji";
$lang['Perform a maintenance check in [Administration>Tools>Maintenance] if you encounter any problem.'] = "Izvršiti proveru održavanja u [Administracija>Alati>Održavanje] ako naiđšete na neki problem.";
$lang['As a precaution, following plugins have been deactivated. You must check for plugins upgrade before reactiving them:'] = "Kao meru predostrožnost, dati dodaci su deaktivirani. Morate proveriti za nadogradnju dodataka pre nego ih ponovo aktivirate :";
$lang['Only administrator can run upgrade: please sign in below.'] = "Samo administrator može da pokrene nadogradnju: prijavite se ispod.";
$lang['You do not have access rights to run upgrade'] = "Nemate pristupna prava da pokrenete nadogradnju";
$lang['All sub-albums of private albums become private'] = "Sve podkategorije privatnih kategorija postaju privatne";
$lang['User permissions and group permissions have been erased'] = "Korisničke i grupne dozvole su obrisane";
$lang['Only thumbnails prefix and webmaster mail address have been saved from previous configuration'] = "Samo prefix za povezne sličice i webmaster e-mail adresa su sačuvane iz prethodne konfiguracije";
$lang['As a precaution, following themes have been deactivated. You must check for themes upgrade before reactiving them:'] = 'Iz predustrožnosti, sledeće teme su deaktivirane. Proverite nadogradnje tema pre nego što ih reaktivirate:';
$lang['In <i>%s</i>, before <b>?></b>, insert:'] = 'U <i>%s</i>, pre <b>?></b>, dodajte:';
?>
